==> igniteui-react-charts-18.5.0-beta.0.tgz: package/esm5/lib/igr-item-tool-tip-layer.js <==
import { __extends } from "tslib";
import { IgrSeries } from "./igr-series";
import { IgrAnnotationLayer } from "./igr-annotation-layer";
import { ItemToolTipLayer } from "./ItemToolTipLayer";
import { ensureBool } from "igniteui-react-core";
/**
 * Represents an annotation layer that displays tooltips for all target series individually.
*/
var IgrItemToolTipLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrItemToolTipLayer, _super);
    function IgrItemToolTipLayer(props) {
        return _super.call(this, props) || this;
    }
    IgrItemToolTipLayer.prototype.createImplementation = function () {
        return new ItemToolTipLayer();
    };
    Object.defineProperty(IgrItemToolTipLayer.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrItemToolTipLayer.prototype, "isAnnotationHoverLayer", {
        /**
         * Gets whether the series is an annotation layer displayed only when hovering over the chart.
        */
        get: function () {
            return this.i.d5;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrItemToolTipLayer.prototype, "isDefaultTooltipBehaviorDisabled", {
        /**
         * Gets whether the default tooltip behaviors for the chart are disabled if this layer is present.
        */
        get: function () {
            return this.i.eg;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrItemToolTipLayer.prototype, "targetSeriesName", {
        /**
         * Gets or sets the name of the series series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
        get: function () {
            return this.i.w7;
        },
        set: function (v) {
            this.i.w7 = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrItemToolTipLayer.prototype, "targetSeries", {
        /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
        get: function () {
            var r = this.i.w1;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrSeries._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.w1 = null : this.i.w1 = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrItemToolTipLayer.prototype, "useInterpolation", {
        /**
         * Gets or sets whether to use value interpolation when drawing the tooltips.
        */
        get: function () {
            return this.i.w4;
        },
        set: function (v) {
            this.i.w4 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrItemToolTipLayer.prototype, "skipUnknownValues", {
        /**
         * Gets or sets whether to skip past unknown values when searching for series values.
        */
        get: function () {
            return this.i.w3;
        },
        set: function (v) {
            this.i.w3 = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgrItemToolTipLayer.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.targetSeries && this.targetSeries.name && this.targetSeries.name == name) {
            return this.targetSeries;
        }
        return null;
    };
    IgrItemToolTipLayer.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.targetSeries && this.targetSeries._styling) {
            this.targetSeries._styling(container, component, this);
        }
        this._inStyling = false;
    };
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    IgrItemToolTipLayer.prototype.hideToolTips = function () {
        this.i.n8();
    };
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    IgrItemToolTipLayer.prototype.hideToolTipsImmediate = function () {
        this.i.n9();
    };
    return IgrItemToolTipLayer;
}(IgrAnnotationLayer));
export { IgrItemToolTipLayer };

==> igniteui-react-charts-18.7.4-beta.0.tgz: package/esm5/lib/igr-item-tool-tip-layer.js <==
import { __extends } from "tslib";
import { IgrSeries } from "./igr-series";
import { IgrAnnotationLayer } from "./igr-annotation-layer";
import { ItemToolTipLayer } from "./ItemToolTipLayer";
import { ensureBool } from "igniteui-react-core";
/**
 * Represents an annotation layer that displays tooltips for all target series individually.
*/
var IgrItemToolTipLayer = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(IgrItemToolTipLayer, _super);
    function IgrItemToolTipLayer(props) {
        return _super.call(this, props) || this;
    }
    IgrItemToolTipLayer.prototype.createImplementation = function () {
        return new ItemToolTipLayer();
    };
    Object.defineProperty(IgrItemToolTipLayer.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrItemToolTipLayer.prototype, "isAnnotationHoverLayer", {
        /**
         * Gets whether the series is an annotation layer displayed only when hovering over the chart.
        */
        get: function () {
            return this.i.eq;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrItemToolTipLayer.prototype, "isDefaultTooltipBehaviorDisabled", {
        /**
         * Gets whether the default tooltip behaviors for the chart are disabled if this layer is present.
        */
        get: function () {
            return this.i.e1;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrItemToolTipLayer.prototype, "targetSeriesName", {
        /**
         * Gets or sets the name of the series series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
        get: function () {
            return this.i.zz;
        },
        set: function (v) {
            this.i.zz = v;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrItemToolTipLayer.prototype, "targetSeries", {
        /**
         * Gets or sets the series to target this annotation to. If null, this annotation targets all series simultaneously.
        */
        get: function () {
            var r = this.i.zt;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = IgrSeries._createFromInternal(r);
                if (e) {
                    e._implementation = r;
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            if (v != null && this._stylingContainer && v._styling)
                v._styling(this._stylingContainer, this, this);
            v == null ? this.i.zt = null : this.i.zt = v.i;
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrItemToolTipLayer.prototype, "useInterpolation", {
        /**
         * Gets or sets whether to use value interpolation when drawing the tooltips.
        */
        get: function () {
            return this.i.zw;
        },
        set: function (v) {
            this.i.zw = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    Object.defineProperty(IgrItemToolTipLayer.prototype, "skipUnknownValues", {
        /**
         * Gets or sets whether to skip past unknown values when searching for series values.
        */
        get: function () {
            return this.i.zv;
        },
        set: function (v) {
            this.i.zv = ensureBool(v);
        },
        enumerable: false,
        configurable: true
    });
    IgrItemToolTipLayer.prototype.findByName = function (name) {
        var baseResult = _super.prototype.findByName.call(this, name);
        if (baseResult) {
            return baseResult;
        }
        if (this.targetSeries && this.targetSeries.name && this.targetSeries.name == name) {
            return this.targetSeries;
        }
        return null;
    };
    IgrItemToolTipLayer.prototype._styling = function (container, component, parent) {
        _super.prototype._styling.call(this, container, component, parent);
        this._inStyling = true;
        if (this.targetSeries && this.targetSeries._styling) {
            this.targetSeries._styling(container, component, this);
        }
        this._inStyling = false;
    };
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    IgrItemToolTipLayer.prototype.hideToolTips = function () {
        this.i.p4();
    };
    /**
     * Hides any tooltips presented by the layer, if any.
    
    */
    IgrItemToolTipLayer.prototype.hideToolTipsImmediate = function () {
        this.i.p5();
    };
    return IgrItemToolTipLayer;
}(IgrAnnotationLayer));
export { IgrItemToolTipLayer };
